@@ -26,7 +26,7 @@ from enum import Enum
 from pathlib import Path
 from shutil import which
 from textwrap import dedent, indent, shorten
-from typing import ContextManager, Dict, Iterable, Iterator, Optional, Union, cast
+from typing import ContextManager, Iterator, Optional, Tuple
 from unittest.mock import patch
 
 if sys.version_info >= (3, 8):
@@ -36,10 +36,17 @@ else:
 
 from boltons.iterutils import flatten
 from boltons.strutils import strip_ansi
-from click_extra.colorize import theme
+from click_extra.colorize import default_theme as theme
 from click_extra.platform import CURRENT_OS_ID, is_linux
-from click_extra.run import INDENT, format_cli, run_cmd
-from click_extra.tests.conftest import ExtraCliRunner
+from click_extra.run import (
+    INDENT,
+    Arg,
+    EnvVars,
+    NestedArgs,
+    args_cleanup,
+    format_cli,
+    run_cmd,
+)
 
 from . import logger
 from .version import TokenizedString, parse_version
@@ -143,19 +150,6 @@ def packages_asdict(packages: Iterator[Package], keep_fields: tuple[str, ...]):
     return ({k: v for k, v in asdict(p).items() if k in keep_fields} for p in packages)
 
 
-_EnvVars = Optional[Dict[str, str]]
-
-# XXX Recursive types are not supported by mypy yet: https://github.com/python/mypy/issues/731
-# _NestedArgs = Iterable[Union[str, Path, None, Iterable["_NestedArgs"]]]
-_Arg = Union[str, Path, None]
-_Args = Iterable[_Arg]
-_NestedArgs = Iterable[
-    Union[
-        _Arg, Iterable[Union[_Arg, Iterable[Union[_Arg, Iterable[Union[_Arg, _Args]]]]]]
-    ]
-]
-
-
 class MetaPackageManager(type):
     """Custom metaclass used as a class factory for package managers."""
 
@@ -236,7 +230,7 @@ class PackageManager(metaclass=MetaPackageManager):
     works well on all platforms.
     """
 
-    extra_env: _EnvVars = None
+    extra_env: EnvVars | None = None
     """Additional environment variables to add to the current context.
 
     Automatically applied on each :py:func:`meta_package_manager.base.PackageManager.run_cli`
@@ -339,7 +333,7 @@ class PackageManager(metaclass=MetaPackageManager):
 
         Returns ``None`` if the CLI was not found or is not a file.
 
-        ..caution::
+        .. caution::
 
             Symlinks are not resolved, because some manager like Homebrew on Linux relies on some
             sort of symlink-based trickery to set environment variables.
@@ -357,11 +351,11 @@ class PackageManager(metaclass=MetaPackageManager):
         if not cli_path.exists():
             raise FileNotFoundError(cli_path)
         elif not cli_path.is_file():
-            logger.warning(f"{theme.invoked_command(cli_path)} is not a file.")
+            logger.warning(f"{theme.invoked_command(str(cli_path))} is not a file.")
             return None
 
         logger.debug(
-            f"{theme.invoked_command(cli_name)} CLI found at {theme.invoked_command(cli_path)}"
+            f"{theme.invoked_command(cli_name)} CLI found at {theme.invoked_command(str(cli_path))}"
         )
         return cli_path
 
@@ -412,7 +406,7 @@ class PackageManager(metaclass=MetaPackageManager):
                 # application" error.
                 if getattr(ex, "winerror", None) == 193:
                     logger.debug(
-                        f"{theme.invoked_command(self.cli_path)} is not a valid Windows application."
+                        f"{theme.invoked_command(str(self.cli_path))} is not a valid Windows application."
                     )
                     # Declare CLI as un-executable.
                     self.executable = False
@@ -481,7 +475,7 @@ class PackageManager(metaclass=MetaPackageManager):
         )
         return bool(self.supported and self.cli_path and self.executable and self.fresh)
 
-    def run(self, *args: _Arg | _NestedArgs, extra_env: _EnvVars = None) -> str:
+    def run(self, *args: Arg | NestedArgs, extra_env: EnvVars | None = None) -> str:
         """Run a shell command, return the output and accumulate error messages.
 
         ``args`` is allowed to be a nested structure of iterables, in which case it will
@@ -499,7 +493,7 @@ class PackageManager(metaclass=MetaPackageManager):
             Move :option:`mpm --dry-run` option and this method to `click-extra <https://github.com/kdeldycke/click-extra>`_.
         """
         # Casting to string helps serialize Path and Version objects.
-        clean_args = ExtraCliRunner._args_cleanup(*args)
+        clean_args = args_cleanup(*args)
         cli_msg = format_cli(clean_args, extra_env)
 
         code = 0
@@ -541,14 +535,14 @@ class PackageManager(metaclass=MetaPackageManager):
 
     def build_cli(
         self,
-        *args: _Arg | _NestedArgs,
+        *args: Arg | NestedArgs,
         auto_pre_cmds: bool = True,
         auto_pre_args: bool = True,
         auto_post_args: bool = True,
-        override_pre_cmds: _NestedArgs | None = None,
+        override_pre_cmds: NestedArgs | None = None,
         override_cli_path: Path | None = None,
-        override_pre_args: _NestedArgs | None = None,
-        override_post_args: _NestedArgs | None = None,
+        override_pre_args: NestedArgs | None = None,
+        override_post_args: NestedArgs | None = None,
         sudo: bool = False,
     ) -> tuple[str, ...]:
         """Build the package manager CLI by combining the custom ``*args`` with the
@@ -587,7 +581,7 @@ class PackageManager(metaclass=MetaPackageManager):
         On linux, the command can be run with `sudo <https://www.sudo.ws>`_ if the parameter of the same name is set to ``True``.
         In which case the ``override_pre_cmds`` parameter is not allowed to be set and the ``auto_pre_cmds`` parameter is forced to ``False``.
         """
-        params: list[_Arg | _NestedArgs] = []
+        params: list[Arg | NestedArgs] = []
 
         # Sudo replaces any pre-command, be it overridden or automatic.
         if sudo:
@@ -621,20 +615,20 @@ class PackageManager(metaclass=MetaPackageManager):
         elif auto_post_args:
             params.extend(self.post_args)
 
-        return ExtraCliRunner._args_cleanup(cast(_NestedArgs, params))
+        return args_cleanup(params)  # type: ignore
 
     def run_cli(
         self,
-        *args: _Arg | _NestedArgs,
+        *args: Arg | NestedArgs,
         auto_extra_env: bool = True,
         auto_pre_cmds: bool = True,
         auto_pre_args: bool = True,
         auto_post_args: bool = True,
-        override_extra_env: _EnvVars = None,
-        override_pre_cmds: _NestedArgs | None = None,
+        override_extra_env: EnvVars | None = None,
+        override_pre_cmds: NestedArgs | None = None,
         override_cli_path: Path | None = None,
-        override_pre_args: _NestedArgs | None = None,
-        override_post_args: _NestedArgs | None = None,
+        override_pre_args: NestedArgs | None = None,
+        override_post_args: NestedArgs | None = None,
         force_exec: bool = False,
         sudo: bool = False,
     ) -> str:
