@@ -26,7 +26,6 @@ from functools import partial
 from io import TextIOWrapper
 from operator import attrgetter
 from pathlib import Path
-from typing import Iterator
 from unittest.mock import patch
 
 import tomli_w
@@ -34,7 +33,9 @@ from boltons.cacheutils import LRI, cached
 from click_extra import STRING, Choice, File, Option
 from click_extra import Path as ClickPath
 from click_extra import argument, echo, extra_group, option, option_group, pass_context
-from click_extra.colorize import KO, OK, highlight, theme
+from click_extra.colorize import KO, OK
+from click_extra.colorize import default_theme as theme
+from click_extra.colorize import highlight
 from click_extra.platform import os_label
 from click_extra.tabulate import table_format_option
 
@@ -83,7 +84,7 @@ def add_manager_to_selection(ctx, param, selected):
         ctx.obj["single_manager_selector"].append(manager_id)
 
 
-def single_manager_selectors() -> Iterator[Option]:
+def single_manager_selectors():
     """Dynamiccaly creates a dedicated flag selector alias for each manager."""
     for manager_id in pool.all_manager_ids:
         yield option(
