@@ -15,12 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+from __future__ import annotations
+
 import json
+from typing import Iterator
 
 from click_extra.platform import LINUX, MACOS, WINDOWS
 
-from .. import logger
 from ..base import Package, PackageManager
+from ..capabilities import search_capabilities
 
 
 class APM(PackageManager):
@@ -47,7 +50,7 @@ class APM(PackageManager):
     """
 
     @property
-    def installed(self):
+    def installed(self) -> Iterator[Package]:
         """Fetch installed packages.
 
         .. code-block:: shell-session
@@ -147,14 +150,14 @@ class APM(PackageManager):
         if output:
             for package_list in json.loads(output).values():
                 for pkg in package_list:
-                    yield Package(
+                    yield self.package(
                         id=pkg["name"],
                         description=pkg["description"],
                         installed_version=pkg["version"],
                     )
 
     @property
-    def outdated(self):
+    def outdated(self) -> Iterator[Package]:
         """Fetch outdated packages.
 
         .. code-block:: shell-session
@@ -308,14 +311,15 @@ class APM(PackageManager):
 
         if output:
             for pkg in json.loads(output):
-                yield Package(
+                yield self.package(
                     id=pkg["name"],
                     description=pkg["description"],
                     installed_version=pkg["version"],
                     latest_version=pkg["latestVersion"],
                 )
 
-    def search(self, query, extended, exact):
+    @search_capabilities(exact_support=False)
+    def search(self, query: str, extended: bool, exact: bool) -> Iterator[Package]:
         """Fetch matching packages.
 
         .. caution::
@@ -402,9 +406,6 @@ class APM(PackageManager):
 
             ► apm search --no-description --json python | jq
         """
-        if exact:
-            logger.warning(f"{self.id} does not implement exact search operation.")
-
         search_args = []
         if not extended:
             search_args.append("--no-description")
@@ -413,13 +414,13 @@ class APM(PackageManager):
 
         if output:
             for pkg in json.loads(output):
-                yield Package(
+                yield self.package(
                     id=pkg["name"],
                     description=pkg["description"],
                     latest_version=pkg["version"],
                 )
 
-    def install(self, package_id):
+    def install(self, package_id: str) -> str:
         """Install one package.
 
         .. code-block:: shell-session
@@ -432,13 +433,19 @@ class APM(PackageManager):
         """
         return self.run_cli("install", package_id)
 
-    def upgrade_cli(self, package_id=None):
+    def upgrade_all_cli(self) -> tuple[str, ...]:
         """Generates the CLI to upgrade all packages (default) or only the one provided
         as parameter.
 
         .. code-block:: shell-session
 
             ► apm update --no-confirm
+        """
+        return self.build_cli("update", "--no-confirm")
+
+    def upgrade_one_cli(self, package_id: str) -> tuple[str, ...]:
+        """Generates the CLI to upgrade all packages (default) or only the one provided
+        as parameter.
 
         .. code-block:: shell-session
 
