@@ -15,12 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+from __future__ import annotations
+
 import re
+from typing import Iterator
 
 from click_extra.platform import LINUX
 
-from .. import logger
 from ..base import Package, PackageManager
+from ..capabilities import search_capabilities
 
 
 class APT(PackageManager):
@@ -51,7 +54,7 @@ class APT(PackageManager):
     """
 
     @property
-    def installed(self):
+    def installed(self) -> Iterator[Package]:
         """Fetch installed packages.
 
         .. code-block:: shell-session
@@ -90,10 +93,10 @@ class APT(PackageManager):
             match = regexp.match(package)
             if match:
                 package_id, installed_version = match.groups()
-                yield Package(id=package_id, installed_version=installed_version)
+                yield self.package(id=package_id, installed_version=installed_version)
 
     @property
-    def outdated(self):
+    def outdated(self) -> Iterator[Package]:
         """Fetch outdated packages.
 
         .. code-block:: shell-session
@@ -110,13 +113,13 @@ class APT(PackageManager):
             match = regexp.match(package)
             if match:
                 package_id, latest_version, installed_version = match.groups()
-                yield Package(
+                yield self.package(
                     id=package_id,
                     latest_version=latest_version,
                     installed_version=installed_version,
                 )
 
-    def search(self, query, extended, exact):
+    def search(self, query: str, extended: bool, exact: bool) -> Iterator[Package]:
         """Fetch matching packages.
 
         .. code-block:: shell-session
@@ -194,11 +197,11 @@ class APT(PackageManager):
         )
 
         for package_id, version, description in regexp.findall(output):
-            yield Package(
+            yield self.package(
                 id=package_id, description=description, latest_version=version
             )
 
-    def install(self, package_id):
+    def install(self, package_id: str) -> str:
         """Install one package.
 
         .. code-block:: shell-session
@@ -207,25 +210,29 @@ class APT(PackageManager):
         """
         return self.run_cli("install", package_id, "--yes", sudo=True)
 
-    def upgrade_cli(self, package_id=None):
+    def upgrade_all_cli(self) -> tuple[str, ...]:
         """Generates the CLI to upgrade all packages (default) or only the one provided
         as parameter.
 
         .. code-block:: shell-session
 
             ► sudo apt upgrade --yes --quiet
+        """
+        return self.build_cli("upgrade", "--yes", sudo=True)
+
+    def upgrade_one_cli(self, package_id: str) -> tuple[str, ...]:
+        """Generates the CLI to upgrade all packages (default) or only the one provided
+        as parameter.
 
         .. code-block:: shell-session
 
             ► sudo apt install --only-upgrade git --yes --quiet
         """
-        params = ("upgrade",)
-        if package_id:
-            params = ("install", "--only-upgrade", package_id)
+        return self.build_cli(
+            "install", "--only-upgrade", package_id, "--yes", sudo=True
+        )
 
-        return self.build_cli(*params, "--yes", sudo=True)
-
-    def sync(self):
+    def sync(self) -> None:
         """Sync package metadata.
 
         .. code-block:: shell-session
@@ -242,7 +249,7 @@ class APT(PackageManager):
         """
         self.run_cli("update", "--yes", sudo=True)
 
-    def cleanup(self):
+    def cleanup(self) -> None:
         """Removes things we don't need anymore.
 
         .. code-block:: shell-session
@@ -275,7 +282,8 @@ class APT_Mint(APT):
         1.6.11
     """
 
-    def search(self, query, extended, exact):
+    @search_capabilities(extended_support=False)
+    def search(self, query: str, extended: bool, exact: bool) -> Iterator[Package]:
         """Fetch matching packages.
 
         .. caution::
@@ -295,9 +303,6 @@ class APT_Mint(APT):
             i   sed              - GNU stream editor
             p   sed:i386         - GNU stream editor
         """
-        if extended:
-            logger.warning(f"{self.id} does not implement extended search operation.")
-
         if exact:
             # Rely on apt regexp support to speed-up exact match.
             query = f"^{query}$"
@@ -319,4 +324,4 @@ class APT_Mint(APT):
         )
 
         for package_id, description in regexp.findall(output):
-            yield Package(id=package_id, description=description)
+            yield self.package(id=package_id, description=description)
