@@ -15,7 +15,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+from __future__ import annotations
+
 import re
+from typing import Iterator
 
 from click_extra.platform import WINDOWS
 
@@ -42,7 +45,7 @@ class Choco(PackageManager):
     """
 
     @property
-    def installed(self):
+    def installed(self) -> Iterator[Package]:
         """Fetch installed packages.
 
         .. code-block:: shell-session
@@ -62,10 +65,10 @@ class Choco(PackageManager):
             match = regexp.match(package)
             if match:
                 package_id, installed_version = match.groups()
-                yield Package(id=package_id, installed_version=installed_version)
+                yield self.package(id=package_id, installed_version=installed_version)
 
     @property
-    def outdated(self):
+    def outdated(self) -> Iterator[Package]:
         """Fetch outdated packages.
 
         .. code-block:: shell-session
@@ -87,13 +90,13 @@ class Choco(PackageManager):
             match = regexp.match(package)
             if match:
                 package_id, installed_version, latest_version = match.groups()
-                yield Package(
+                yield self.package(
                     id=package_id,
                     latest_version=latest_version,
                     installed_version=installed_version,
                 )
 
-    def search(self, query, extended, exact):
+    def search(self, query: str, extended: bool, exact: bool) -> Iterator[Package]:
         """Fetch matching packages.
 
         .. code-block:: shell-session
@@ -137,9 +140,9 @@ class Choco(PackageManager):
 
         regexp = re.compile(r"(.+)\|(.+)")
         for package_id, latest_version in regexp.findall(output):
-            yield Package(id=package_id, latest_version=latest_version)
+            yield self.package(id=package_id, latest_version=latest_version)
 
-    def install(self, package_id):
+    def install(self, package_id: str) -> str:
         """Install one package.
 
         .. code-block:: shell-session
@@ -148,13 +151,19 @@ class Choco(PackageManager):
         """
         return self.run_cli("install", package_id, "--yes", "--limit-output")
 
-    def upgrade_cli(self, package_id="all"):
+    def upgrade_all_cli(self) -> tuple[str, ...]:
         """Generates the CLI to upgrade all packages (default) or only the one provided
         as parameter.
 
         .. code-block:: shell-session
 
             ► choco upgrade all --yes --limit-output --no-progress --no-color
+        """
+        return self.build_cli("upgrade", "all", "--yes", "--limit-output")
+
+    def upgrade_one_cli(self, package_id) -> tuple[str, ...]:
+        """Generates the CLI to upgrade all packages (default) or only the one provided
+        as parameter.
 
         .. code-block:: shell-session
 
