@@ -22,13 +22,17 @@
     Some of these are good candidates for upstream contribution to ``click.extra``.
 """
 
+from __future__ import annotations
+
 import builtins
 import json
 import sys
+from collections import Counter
 from functools import partial
 from io import StringIO
 from operator import itemgetter
 from pathlib import Path
+from typing import Any, Sequence
 from unittest.mock import patch
 
 if sys.version_info >= (3, 8):
@@ -42,7 +46,7 @@ from click_extra import echo, get_current_context, style
 from click_extra.tabulate import TabularOutputFormatter
 from tabulate import DataRow, TableFormat, tabulate
 
-from .bar_plugin import MPMPlugin
+from .bar_plugin import MPMPlugin  # type: ignore
 from .version import TokenizedString
 
 SORTABLE_FIELDS = {
@@ -173,13 +177,15 @@ def print_table(header_defs, rows, sort_key=None):
         """Serialize line's content for natural sorting.
 
         1. Extract each cell value in the order provided by `sort_order`;
-        2. Strip terminal color formating;
+        2. Strip terminal color formatting;
         3. Then tokenize each cell's content for user-friendly natural sorting.
         """
         sorting_key = []
         for cell in itemgetter(*sort_order)(line):
             if isinstance(cell, TokenizedString):
                 key = cell
+            elif not cell:
+                key = None
             else:
                 key = TokenizedString(strip_ansi(cell))
             sorting_key.append(key)
@@ -191,8 +197,8 @@ def print_table(header_defs, rows, sort_key=None):
     )
 
 
-def print_stats(data):
-    """Prints statistics to ``stdout``: total packages and a break down by package
+def print_stats(manager_stats: Counter) -> None:
+    """Prints statistics to ``<stdout>``: total packages and a break down by package
     manager.
 
     Prints something like:
@@ -201,18 +207,17 @@ def print_stats(data):
 
         16 packages total (brew: 2, pip: 2, apm: 2, gem: 2, cask: 2, mas: 2, vscode: 2, npm: 2, composer: 0).
     """
-    manager_stats = {infos["id"]: len(infos["packages"]) for infos in data.values()}
-    total_installed = sum(manager_stats.values())
-    per_manager_totals = ", ".join(
-        (
-            f"{k}: {v}"
-            for k, v in sorted(manager_stats.items(), key=itemgetter(1), reverse=True)
+    per_manager_totals = ""
+    if manager_stats:
+        per_manager_totals = (
+            f" ({', '.join(f'{k}: {v}' for k, v in manager_stats.most_common())})"
         )
-    )
-    if per_manager_totals:
-        per_manager_totals = f" ({per_manager_totals})"
-    plural = "s" if total_installed > 1 else ""
-    echo(f"{total_installed} package{plural} total{per_manager_totals}.")
+    if sys.version_info >= (3, 10):
+        total = manager_stats.total()
+    else:
+        total = sum(manager_stats.values())
+    plural = "s" if total > 1 else ""
+    echo(f"{total} package{plural} total{per_manager_totals}.")
 
 
 class BarPluginRenderer(MPMPlugin):
@@ -288,7 +293,7 @@ class BarPluginRenderer(MPMPlugin):
         self.pp(*args, "terminal=false")
         self.pp(*args, "terminal=true", "alternate=true")
 
-    def print_upgrade_all_item(self, manager, submenu=""):
+    def print_upgrade_all_item(self, manager: dict, submenu: str = "") -> None:
         """Print the menu entry to upgrade all outdated package of a manager."""
         if manager.get("upgrade_all_cli"):
             if self.submenu_layout:
@@ -313,7 +318,9 @@ class BarPluginRenderer(MPMPlugin):
     """Simple rendering format with single-space separated columns used in the function below."""
 
     @staticmethod
-    def render_table(table_data):
+    def render_table(
+        table_data: Sequence[Sequence[str]] | None,
+    ) -> Any | list:
         """Renders a table data with pre-configured alignment centered around the third
         column.
 
@@ -330,6 +337,12 @@ class BarPluginRenderer(MPMPlugin):
             xmlrpc                          0.3.1 → 0.4
             blockblock 5.33,VHSDGataYCcV8xqv5TSZA → 5.39
             sed                                 2 → 2021.0328
+
+        ..todo::
+
+            Use upcoming ``tabulate.SEPARATING_LINE`` to produce the whole bar plugin table in one go
+            and have all version numbers from all managers aligned. See:
+            https://github.com/astanin/python-tabulate/commit/dab256d1f64da97720c1459478a3cc0a4ea7a91e
         """
         if not table_data:
             return []
@@ -340,9 +353,15 @@ class BarPluginRenderer(MPMPlugin):
             disable_numparse=True,
         ).splitlines()
 
-    def _render(self, outdated_data):
+    def _render(self, outdated_data) -> None:
         """Main method implementing the final structured rendering in *Bar plugin
-        dialect."""
+        dialect.
+
+        ..todo::
+
+            Wait for ANSI-aware layout in table to be merged upstream so we can highly version
+            differences in bar plugin. See: https://github.com/astanin/python-tabulate/pull/184
+        """
         managers = outdated_data.values()
         font = self.monospace_font if self.table_rendering else self.default_font
 
@@ -365,7 +384,7 @@ class BarPluginRenderer(MPMPlugin):
 
             table = [
                 (
-                    (p["name"], p["installed_version"], "→", p["latest_version"]),
+                    (p["label"], p["installed_version"], "→", p["latest_version"]),
                     p["upgrade_cli"],
                 )
                 for p in manager["packages"]
@@ -406,7 +425,7 @@ class BarPluginRenderer(MPMPlugin):
                 print("-----" if self.submenu_layout else "---")
                 self.print_error(error_msg, submenu)
 
-    def render(self, outdated_data):
+    def render(self, outdated_data) -> str:
         """Wraps the :py:meth:`meta_package_manager.output.BarPluginRenderer._render`
         function above to capture all ``print`` statements."""
         capture = StringIO()
@@ -415,7 +434,7 @@ class BarPluginRenderer(MPMPlugin):
             self._render(outdated_data)
         return capture.getvalue()
 
-    def print(self, outdated_data):
+    def print(self, outdated_data) -> None:
         """Print the final plugin rendering to ``<stdout>``.
 
         Capturing the output of the plugin and re-printing it will introduce an extra
