@@ -15,6 +15,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+from __future__ import annotations
+
 import pytest
 from click_extra.tests.conftest import destructive
 
@@ -75,7 +77,7 @@ class TestInstallRemove(CLISubCommandTests):
         "snap": "standard-notes",
         "steamcmd": "740",
         "vscode": "tamasfe.even-better-toml",
-        "yarn": "markdown",
+        "yarn": "awesome-lint",
         # https://aur.archlinux.org/packages/meta-package-manager
         "yay": "meta-package-manager",
         "yum": "usd",
