@@ -15,48 +15,88 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+from __future__ import annotations
+
 import subprocess
+from pathlib import Path
 
 import pytest
 from click_extra.run import env_copy
 from click_extra.tests.conftest import destructive, unless_macos
 
-# Default location of Homebrew Cask formulas on macOS. This is supposed to be a
-# shallow copy of the following Git repository:
-# https://github.com/Homebrew/homebrew-cask
-CASK_PATH = "/usr/local/Homebrew/Library/Taps/homebrew/homebrew-cask/Casks/"
-
 
 @pytest.fixture
 def install_cask():
-
     packages = set()
 
+    def get_cask_path():
+        """Default location of Homebrew Cask formulas on macOS.
+
+        This is supposed to be a shallow copy of the following Git repository:
+        https://github.com/Homebrew/homebrew-cask
+        """
+        process = subprocess.run(
+            ("brew", "--repository"),
+            capture_output=True,
+            encoding="utf-8",
+        )
+        assert process.returncode == 0
+        assert not process.stderr
+        assert process.stdout
+
+        brew_root = Path(process.stdout.strip())
+        assert brew_root.is_absolute()
+        assert brew_root.exists()
+        assert brew_root.is_dir()
+
+        cask_repo = brew_root.joinpath("Library/Taps/homebrew/homebrew-cask/Casks/")
+        assert cask_repo.is_absolute()
+        assert cask_repo.exists()
+        assert cask_repo.is_dir()
+        return cask_repo
+
     def git_checkout(package_id, commit):
         process = subprocess.run(
-            ("git", "-C", CASK_PATH, "checkout", commit, f"{package_id}.rb")
+            ("git", "-C", get_cask_path(), "checkout", commit, f"{package_id}.rb")
         )
+        assert not process.stderr
+        assert process.returncode == 0
+
+    def brew_cleanup():
+        process = subprocess.run(
+            ("brew", "cleanup", "-s", "--prune=all"),
+            env=env_copy({"HOMEBREW_NO_AUTO_UPDATE": "1"}),
+        )
+        assert not process.stderr
         assert process.returncode == 0
 
     def _install_cask(package_id, commit):
         packages.add(package_id)
+
         # Fetch locally the old version of the Cask's formula.
         git_checkout(package_id, commit)
+        brew_cleanup()
+
         # Install the cask but bypass its local cache auto-update: we want to
         # force brew to rely on our formula from the past.
         process = subprocess.run(
             ("brew", "reinstall", "--cask", package_id),
             capture_output=True,
             encoding="utf-8",
-            env=env_copy({"HOMEBREW_NO_AUTO_UPDATE": "1"}),
+            env=env_copy(
+                {"HOMEBREW_NO_ENV_HINTS": "1", "HOMEBREW_NO_AUTO_UPDATE": "1"}
+            ),
         )
+
         # Restore old formula to its most recent version.
         git_checkout(package_id, "HEAD")
+        brew_cleanup()
+
         # Check the cask has been properly installed.
-        assert process.returncode == 0
         if process.stderr:
             assert "is already installed" not in process.stderr
         assert f"{package_id} was successfully installed!" in process.stdout
+        assert process.returncode == 0
         return process.stdout
 
     yield _install_cask
@@ -69,12 +109,13 @@ def install_cask():
 @destructive
 @unless_macos
 class TestCask:
+    @pytest.mark.xdist_group(name="avoid_concurrent_git_tweaks")
     def test_autoupdate_unicode_name(self, invoke, install_cask):
         """See #16."""
         # Install an old version of a package with a unicode name.
-        # Old Cask formula for ubersicht 1.4.60.
-        output = install_cask("ubersicht", "bb72da6c085c017f6bccebbfee5e3bc4837f3165")
-        assert "Uebersicht-1.4.60.app.zip" in output
+        # Old Cask formula for ubersicht 1.6.69.
+        output = install_cask("ubersicht", "9870e8ffaa8dc83403973580415b2c56dc760f15")
+        assert "Uebersicht-1.6.69.app.zip" in output
         assert "Übersicht.app" in output
         assert "Übersicht.app" not in output
 
@@ -98,12 +139,13 @@ class TestCask:
         # Outdated subcommand does not fetch the unicode name by default.
         assert "Übersicht" not in result.stdout
 
+    @pytest.mark.xdist_group(name="avoid_concurrent_git_tweaks")
     def test_multiple_names(self, invoke, install_cask):
         """See #26."""
         # Install an old version of a package with multiple names.
-        # Old Cask formula for xld 2018.10.19.
-        output = install_cask("xld", "89536da7075aa3ac9683a67189fddbed4a7d818c")
-        assert "xld-20181019.dmg" in output
+        # Old Cask formula for xld 20210101,153.1.
+        output = install_cask("xld", "6be43816ea729c18219322f656c62a702e1c2440")
+        assert "xld-20210101.dmg" in output
         assert "XLD.app" in output
 
         # Look for reported available upgrade.
