@@ -15,7 +15,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+from __future__ import annotations
+
 import ast
+import inspect
 import re
 import types
 from operator import attrgetter
@@ -28,7 +31,7 @@ from boltons.iterutils import unique
 from boltons.urlutils import URL
 from click_extra.platform import OS_DEFINITIONS
 
-from ..base import Package, PackageManager
+from ..base import Operations, Package, PackageManager
 from ..cli import XKCD_MANAGER_ORDER
 from ..pool import pool
 from ..version import TokenizedString
@@ -205,10 +208,6 @@ def test_available(manager):
     assert isinstance(manager.available, bool)
 
 
-# TODO:
-# def test_args_cleanup():
-
-
 @all_managers
 def test_installed_type(manager):
     """All installed operations are either not implemented or returns a dict of
@@ -219,9 +218,7 @@ def test_installed_type(manager):
         except Exception as ex:
             assert isinstance(ex, NotImplementedError)
         else:
-            # XXX There is an exception in the way npm.installed is implemented as it use a recursive
-            # boltons.remap strategy to parse the tree-like JSON.
-            assert isinstance(result, (list, types.GeneratorType))
+            assert isinstance(result, types.GeneratorType)
             for pkg in result:
                 assert isinstance(pkg, Package)
 
@@ -270,12 +267,12 @@ def test_search_type(manager):
 
 
 @all_managers
-def test_upgrade_cli_type(manager):
+def test_upgrade_one_cli_type(manager):
     """All methods returning an upgrade CLI are either not implemented or returns a
     tuple."""
-    assert isinstance(manager.upgrade_cli, MethodType)
+    assert isinstance(manager.upgrade_one_cli, MethodType)
     try:
-        result = manager.upgrade_cli("dummy_package_id")
+        result = manager.upgrade_one_cli("dummy_package_id")
     except Exception as ex:
         assert isinstance(ex, NotImplementedError)
     else:
@@ -321,12 +318,48 @@ def test_cleanup_type(manager):
             assert result is None
 
 
-# Build the canonical reference from the base class.
-# The class' internal dict is sorted with the same order the code is
-# structured. No need for AST parsing.
-props_ref = tuple(
-    prop for prop in PackageManager.__dict__.keys() if not prop.startswith("_")
-)
+def collect_props_ref():
+    """Build the canonical reference from the base class.
+
+    We need to parse the AST so we can collect both attributes and naked type
+    annotations.
+    """
+    tree = ast.parse(Path(inspect.getfile(PackageManager)).read_bytes())
+
+    manager_class = None
+    for n in tree.body:
+        if isinstance(n, ast.ClassDef) and n.name == "PackageManager":
+            manager_class = n
+            break
+
+    for node in manager_class.body:
+        if isinstance(node, ast.AnnAssign):
+            yield node.target.id
+        if isinstance(node, ast.Assign):
+            yield from [t.id for t in node.targets]
+        if isinstance(node, ast.FunctionDef):
+            yield node.name
+
+
+props_ref = tuple(collect_props_ref())
+
+
+def test_operation_order():
+    """Double check operation IDs are ordered and aligned to the base manager class and
+    CLI implementation."""
+    direct_operation_ids = [op for op in Operations.__members__ if op != "upgrade_all"]
+
+    base_operations = [p for p in props_ref if p in direct_operation_ids]
+    assert list(direct_operation_ids) == list(base_operations)
+
+    cli_tree = ast.parse(Path(__file__).parent.joinpath("../cli.py").read_bytes())
+    implemented_operations = [
+        n.name
+        for n in cli_tree.body
+        if isinstance(n, ast.FunctionDef) and n.name in direct_operation_ids
+    ]
+    assert list(direct_operation_ids) == list(implemented_operations)
+
 
 # Check the code of each file registered in the pool.
 @pytest.mark.parametrize("manager_file", pool.manager_files, ids=attrgetter("name"))
